import { CamelCase } from 'type-fest';

type CamelCaseOptions = {
    readonly preserveConsecutiveUppercase?: boolean;
};
declare const DEFAULT_OPTIONS: {
    readonly preserveConsecutiveUppercase: true;
};
/**
 * Convert a text to camelCase by splitting it into words, un-capitalizing the
 * first word, capitalizing the rest, then joining them back together. This is
 * the runtime implementation of type-fest's [`CamelCase` type](https://github.com/sindresorhus/type-fest/blob/main/source/camel-case.d.ts).
 *
 * For other case manipulations see: `toLowerCase`, `toUpperCase`, `capitalize`,
 * and `uncapitalize`.
 *
 * For *PascalCase* use `capitalize(toCamelCase(data))`.
 *
 * @param data - A string.
 * @param options - Used to disable the default behavior of preserving
 * consecutive uppercase characters. This is optional.
 * @signature
 *   R.toCamelCase(data);
 * @example
 *   R.toCamelCase("hello world"); // "helloWorld"
 *   R.toCamelCase("__HELLO_WORLD__"); // "helloWorld"
 * @dataFirst
 * @category String
 */
declare function toCamelCase<T extends string, Options extends CamelCaseOptions = typeof DEFAULT_OPTIONS>(data: T, options?: Options): CamelCase<T, Options>;
/**
 * Convert a text to camelCase by splitting it into words, un-capitalizing the
 * first word, capitalizing the rest, then joining them back together. This is
 * the runtime implementation of type-fest's [`CamelCase` type](https://github.com/sindresorhus/type-fest/blob/main/source/camel-case.d.ts).
 *
 * For other case manipulations see: `toLowerCase`, `toUpperCase`, `capitalize`,
 * and `uncapitalize`.
 *
 * !IMPORTANT: This function might work _incorrectly_ for **non-ascii** inputs.
 *
 * For *PascalCase* use `capitalize(toCamelCase(data))`.
 *
 * @param options - Used to disable the default behavior of preserving
 * consecutive uppercase characters. This is optional.
 * @signature
 *   R.toCamelCase()(data);
 * @example
 *   R.pipe("hello world", R.toCamelCase()); // "helloWorld"
 *   R.pipe("__HELLO_WORLD__", toCamelCase()); // "helloWorld"
 * @dataLast
 * @category String
 */
declare function toCamelCase<Options extends CamelCaseOptions = typeof DEFAULT_OPTIONS>(options?: Options): <T extends string>(data: T) => CamelCase<T, Options>;

export { toCamelCase };
